package de.intevation.flys.jfree;

import java.awt.Color;

import org.jfree.chart.plot.IntervalMarker;
import org.w3c.dom.Document;

import de.intevation.flys.utils.ThemeUtil;

/**
 * Marker that represents a highlighted interval.
 *
 * @author <a href="mailto:christian.lins@intevation.de">Christian Lins</a>
 */
public class StyledDomainMarker extends IntervalMarker {

    private static final long serialVersionUID = -4369417661339512342L;

    private final Color backgroundColor, backgroundColor2;

    public StyledDomainMarker(double start, double end, Document theme) {
        super(start, end);

        backgroundColor = ThemeUtil.parseColor(
                ThemeUtil.getAreaBackgroundColorString(theme));
        backgroundColor2 = new Color(
            255 - backgroundColor.getRed(),
            255 - backgroundColor.getGreen(),
            255 - backgroundColor.getBlue());
        useSecondColor(false);

        int alpha = 100 - ThemeUtil.parseInteger(
                ThemeUtil.getAreaTransparencyString(theme), 50);
        setAlpha(alpha / 100.0f);
    }

    /**
     * To properly differentiate several styled domain markers side by side,
     * we can use this switch to toggle between two colors.
     * @param secondColor
     */
    public void useSecondColor(boolean secondColor) {
        if(!secondColor) {
            if(backgroundColor != null)
                setPaint(backgroundColor);
        }
        else {
            if(backgroundColor2 != null)
                setPaint(backgroundColor2);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
